/* SPDX-License-Identifier: (LGPL-2.1 OR BSD-2-Clause) */

/* THIS FILE IS AUTOGENERATED BY BPFTOOL! */
#ifndef __TEST_MMAP_SKEL_H__
#define __TEST_MMAP_SKEL_H__

#include <errno.h>
#include <stdlib.h>
#include <bpf/libbpf.h>

#define BPF_SKEL_SUPPORTS_MAP_AUTO_ATTACH 1

struct test_mmap {
	struct bpf_object_skeleton *skeleton;
	struct bpf_object *obj;
	struct {
		struct bpf_map *data_map;
		struct bpf_map *rdonly_map;
		struct bpf_map *bss;
	} maps;
	struct {
		struct bpf_program *test_mmap;
	} progs;
	struct {
		struct bpf_link *test_mmap;
	} links;
	struct test_mmap__bss {
		__u64 in_val;
		__u64 out_val;
	} *bss;

#ifdef __cplusplus
	static inline struct test_mmap *open(const struct bpf_object_open_opts *opts = nullptr);
	static inline struct test_mmap *open_and_load();
	static inline int load(struct test_mmap *skel);
	static inline int attach(struct test_mmap *skel);
	static inline void detach(struct test_mmap *skel);
	static inline void destroy(struct test_mmap *skel);
	static inline const void *elf_bytes(size_t *sz);
#endif /* __cplusplus */
};

static void
test_mmap__destroy(struct test_mmap *obj)
{
	if (!obj)
		return;
	if (obj->skeleton)
		bpf_object__destroy_skeleton(obj->skeleton);
	free(obj);
}

static inline int
test_mmap__create_skeleton(struct test_mmap *obj);

static inline struct test_mmap *
test_mmap__open_opts(const struct bpf_object_open_opts *opts)
{
	struct test_mmap *obj;
	int err;

	obj = (struct test_mmap *)calloc(1, sizeof(*obj));
	if (!obj) {
		errno = ENOMEM;
		return NULL;
	}

	err = test_mmap__create_skeleton(obj);
	if (err)
		goto err_out;

	err = bpf_object__open_skeleton(obj->skeleton, opts);
	if (err)
		goto err_out;

	return obj;
err_out:
	test_mmap__destroy(obj);
	errno = -err;
	return NULL;
}

static inline struct test_mmap *
test_mmap__open(void)
{
	return test_mmap__open_opts(NULL);
}

static inline int
test_mmap__load(struct test_mmap *obj)
{
	return bpf_object__load_skeleton(obj->skeleton);
}

static inline struct test_mmap *
test_mmap__open_and_load(void)
{
	struct test_mmap *obj;
	int err;

	obj = test_mmap__open();
	if (!obj)
		return NULL;
	err = test_mmap__load(obj);
	if (err) {
		test_mmap__destroy(obj);
		errno = -err;
		return NULL;
	}
	return obj;
}

static inline int
test_mmap__attach(struct test_mmap *obj)
{
	return bpf_object__attach_skeleton(obj->skeleton);
}

static inline void
test_mmap__detach(struct test_mmap *obj)
{
	bpf_object__detach_skeleton(obj->skeleton);
}

static inline const void *test_mmap__elf_bytes(size_t *sz);

static inline int
test_mmap__create_skeleton(struct test_mmap *obj)
{
	struct bpf_object_skeleton *s;
	struct bpf_map_skeleton *map __attribute__((unused));
	int err;

	s = (struct bpf_object_skeleton *)calloc(1, sizeof(*s));
	if (!s)	{
		err = -ENOMEM;
		goto err;
	}

	s->sz = sizeof(*s);
	s->name = "test_mmap";
	s->obj = &obj->obj;

	/* maps */
	s->map_cnt = 3;
	s->map_skel_sz = 24;
	s->maps = (struct bpf_map_skeleton *)calloc(s->map_cnt,
			sizeof(*s->maps) > 24 ? sizeof(*s->maps) : 24);
	if (!s->maps) {
		err = -ENOMEM;
		goto err;
	}

	map = (struct bpf_map_skeleton *)((char *)s->maps + 0 * s->map_skel_sz);
	map->name = "data_map";
	map->map = &obj->maps.data_map;

	map = (struct bpf_map_skeleton *)((char *)s->maps + 1 * s->map_skel_sz);
	map->name = "rdonly_map";
	map->map = &obj->maps.rdonly_map;

	map = (struct bpf_map_skeleton *)((char *)s->maps + 2 * s->map_skel_sz);
	map->name = "test_mma.bss";
	map->map = &obj->maps.bss;
	map->mmaped = (void **)&obj->bss;

	/* programs */
	s->prog_cnt = 1;
	s->prog_skel_sz = sizeof(*s->progs);
	s->progs = (struct bpf_prog_skeleton *)calloc(s->prog_cnt, s->prog_skel_sz);
	if (!s->progs) {
		err = -ENOMEM;
		goto err;
	}

	s->progs[0].name = "test_mmap";
	s->progs[0].prog = &obj->progs.test_mmap;
	s->progs[0].link = &obj->links.test_mmap;

	s->data = test_mmap__elf_bytes(&s->data_sz);

	obj->skeleton = s;
	return 0;
err:
	bpf_object__destroy_skeleton(s);
	return err;
}

static inline const void *test_mmap__elf_bytes(size_t *sz)
{
	static const char data[] __attribute__((__aligned__(8))) = "\
\x7f\x45\x4c\x46\x02\x01\x01\0\0\0\0\0\0\0\0\0\x01\0\xf7\0\x01\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\x98\x0a\0\0\0\0\0\0\0\0\0\0\x40\0\0\0\0\0\x40\0\x0a\0\
\x01\0\0\x2e\x73\x74\x72\x74\x61\x62\0\x2e\x73\x79\x6d\x74\x61\x62\0\x72\x61\
\x77\x5f\x74\x72\x61\x63\x65\x70\x6f\x69\x6e\x74\x2f\x73\x79\x73\x5f\x65\x6e\
\x74\x65\x72\0\x6c\x69\x63\x65\x6e\x73\x65\0\x2e\x62\x73\x73\0\x2e\x6d\x61\x70\
\x73\0\x74\x65\x73\x74\x5f\x6d\x6d\x61\x70\x2e\x63\0\x74\x65\x73\x74\x5f\x6d\
\x6d\x61\x70\0\x69\x6e\x5f\x76\x61\x6c\0\x6f\x75\x74\x5f\x76\x61\x6c\0\x64\x61\
\x74\x61\x5f\x6d\x61\x70\0\x5f\x6c\x69\x63\x65\x6e\x73\x65\0\x72\x64\x6f\x6e\
\x6c\x79\x5f\x6d\x61\x70\0\x2e\x72\x65\x6c\x72\x61\x77\x5f\x74\x72\x61\x63\x65\
\x70\x6f\x69\x6e\x74\x2f\x73\x79\x73\x5f\x65\x6e\x74\x65\x72\0\x2e\x42\x54\x46\
\0\x2e\x42\x54\x46\x2e\x65\x78\x74\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\x3d\0\0\0\x04\0\xf1\xff\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\x03\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x49\0\0\0\x12\0\x03\0\0\0\0\0\
\0\0\0\0\xa0\x01\0\0\0\0\0\0\x53\0\0\0\x11\0\x05\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\
\0\0\0\x5a\0\0\0\x11\0\x05\0\x08\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\x62\0\0\0\x11\
\0\x06\0\0\0\0\0\0\0\0\0\x20\0\0\0\0\0\0\0\x6b\0\0\0\x11\0\x04\0\0\0\0\0\0\0\0\
\0\x04\0\0\0\0\0\0\0\x74\0\0\0\x11\0\x06\0\x20\0\0\0\0\0\0\0\x20\0\0\0\0\0\0\0\
\x18\x06\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x79\x61\0\0\0\0\0\0\x18\x02\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\x7b\x12\0\0\0\0\0\0\xb7\x01\0\0\0\0\0\0\x63\x1a\xfc\xff\0\0\0\0\
\xb7\x01\0\0\x01\0\0\0\x63\x1a\xf8\xff\0\0\0\0\xb7\x01\0\0\x02\0\0\0\x63\x1a\
\xf4\xff\0\0\0\0\xb7\x01\0\0\xdc\x05\0\0\x63\x1a\xf0\xff\0\0\0\0\xbf\xa2\0\0\0\
\0\0\0\x07\x02\0\0\xf4\xff\xff\xff\x18\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x18\x03\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xb7\x04\0\0\0\0\0\0\x85\0\0\0\x02\0\0\0\xbf\xa2\0\
\0\0\0\0\0\x07\x02\0\0\xfc\xff\xff\xff\x18\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x85\
\0\0\0\x01\0\0\0\x15\0\x0b\0\0\0\0\0\x79\x01\0\0\0\0\0\0\x67\x01\0\0\x01\0\0\0\
\x7b\x1a\xe8\xff\0\0\0\0\xbf\xa2\0\0\0\0\0\0\x07\x02\0\0\xf8\xff\xff\xff\xbf\
\xa3\0\0\0\0\0\0\x07\x03\0\0\xe8\xff\xff\xff\x18\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\xb7\x04\0\0\0\0\0\0\x85\0\0\0\x02\0\0\0\x79\x61\0\0\0\0\0\0\x27\x01\0\0\x03\
\0\0\0\x7b\x1a\xe8\xff\0\0\0\0\xbf\xa2\0\0\0\0\0\0\x07\x02\0\0\xf0\xff\xff\xff\
\xbf\xa3\0\0\0\0\0\0\x07\x03\0\0\xe8\xff\xff\xff\x18\x01\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\xb7\x04\0\0\0\0\0\0\x85\0\0\0\x02\0\0\0\xb7\0\0\0\0\0\0\0\x95\0\0\0\0\0\
\0\0\x47\x50\x4c\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\x01\0\0\0\x04\0\0\0\x18\0\0\0\0\0\0\0\x01\0\0\0\x05\0\0\0\x80\0\
\0\0\0\0\0\0\x01\0\0\0\x06\0\0\0\x90\0\0\0\0\0\0\0\x01\0\0\0\x04\0\0\0\xc0\0\0\
\0\0\0\0\0\x01\0\0\0\x06\0\0\0\x18\x01\0\0\0\0\0\0\x01\0\0\0\x06\0\0\0\x70\x01\
\0\0\0\0\0\0\x01\0\0\0\x06\0\0\0\x9f\xeb\x01\0\x18\0\0\0\0\0\0\0\x64\x02\0\0\
\x64\x02\0\0\x95\x02\0\0\0\0\0\0\0\0\0\x02\x03\0\0\0\x01\0\0\0\0\0\0\x01\x04\0\
\0\0\x20\0\0\x01\0\0\0\0\0\0\0\x03\0\0\0\0\x02\0\0\0\x04\0\0\0\x02\0\0\0\x05\0\
\0\0\0\0\0\x01\x04\0\0\0\x20\0\0\0\0\0\0\0\0\0\0\x02\x06\0\0\0\0\0\0\0\0\0\0\
\x03\0\0\0\0\x02\0\0\0\x04\0\0\0\0\x04\0\0\0\0\0\0\0\0\0\x02\x08\0\0\0\x19\0\0\
\0\0\0\0\x08\x09\0\0\0\x1f\0\0\0\0\0\0\x01\x04\0\0\0\x20\0\0\0\0\0\0\0\0\0\0\
\x02\x0b\0\0\0\x2c\0\0\0\0\0\0\x08\x0c\0\0\0\x32\0\0\0\0\0\0\x01\x08\0\0\0\x40\
\0\0\0\0\0\0\0\x04\0\0\x04\x20\0\0\0\x45\0\0\0\x01\0\0\0\0\0\0\0\x4a\0\0\0\x05\
\0\0\0\x40\0\0\0\x54\0\0\0\x07\0\0\0\x80\0\0\0\x58\0\0\0\x0a\0\0\0\xc0\0\0\0\
\x5e\0\0\0\0\0\0\x0e\x0d\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\x02\x10\0\0\0\0\0\0\0\0\
\0\0\x03\0\0\0\0\x02\0\0\0\x04\0\0\0\x80\x04\0\0\0\0\0\0\0\0\0\x02\x12\0\0\0\
\x67\0\0\0\0\0\0\x01\x01\0\0\0\x08\0\0\x01\0\0\0\0\x04\0\0\x04\x20\0\0\0\x45\0\
\0\0\x01\0\0\0\0\0\0\0\x4a\0\0\0\x0f\0\0\0\x40\0\0\0\x54\0\0\0\x07\0\0\0\x80\0\
\0\0\x58\0\0\0\x11\0\0\0\xc0\0\0\0\x6c\0\0\0\0\0\0\x0e\x13\0\0\0\x01\0\0\0\0\0\
\0\0\0\0\0\x02\0\0\0\0\0\0\0\0\x01\0\0\x0d\x02\0\0\0\x77\0\0\0\x15\0\0\0\x7b\0\
\0\0\x01\0\0\x0c\x16\0\0\0\0\0\0\0\0\0\0\x03\0\0\0\0\x12\0\0\0\x04\0\0\0\x04\0\
\0\0\x85\0\0\0\0\0\0\x0e\x18\0\0\0\x01\0\0\0\x8e\0\0\0\0\0\0\x0e\x0b\0\0\0\x01\
\0\0\0\x95\0\0\0\0\0\0\x0e\x0b\0\0\0\x01\0\0\0\x69\x02\0\0\x01\0\0\x0f\x04\0\0\
\0\x19\0\0\0\0\0\0\0\x04\0\0\0\x71\x02\0\0\x02\0\0\x0f\x10\0\0\0\x1a\0\0\0\0\0\
\0\0\x08\0\0\0\x1b\0\0\0\x08\0\0\0\x08\0\0\0\x76\x02\0\0\x02\0\0\x0f\x40\0\0\0\
\x0e\0\0\0\0\0\0\0\x20\0\0\0\x14\0\0\0\x20\0\0\0\x20\0\0\0\0\x69\x6e\x74\0\x5f\
\x5f\x41\x52\x52\x41\x59\x5f\x53\x49\x5a\x45\x5f\x54\x59\x50\x45\x5f\x5f\0\x5f\
\x5f\x75\x33\x32\0\x75\x6e\x73\x69\x67\x6e\x65\x64\x20\x69\x6e\x74\0\x5f\x5f\
\x75\x36\x34\0\x75\x6e\x73\x69\x67\x6e\x65\x64\x20\x6c\x6f\x6e\x67\x20\x6c\x6f\
\x6e\x67\0\x74\x79\x70\x65\0\x6d\x61\x70\x5f\x66\x6c\x61\x67\x73\0\x6b\x65\x79\
\0\x76\x61\x6c\x75\x65\0\x64\x61\x74\x61\x5f\x6d\x61\x70\0\x63\x68\x61\x72\0\
\x72\x64\x6f\x6e\x6c\x79\x5f\x6d\x61\x70\0\x63\x74\x78\0\x74\x65\x73\x74\x5f\
\x6d\x6d\x61\x70\0\x5f\x6c\x69\x63\x65\x6e\x73\x65\0\x69\x6e\x5f\x76\x61\x6c\0\
\x6f\x75\x74\x5f\x76\x61\x6c\0\x2f\x62\x75\x69\x6c\x64\x64\x69\x72\x2f\x62\x75\
\x69\x6c\x64\x2f\x42\x55\x49\x4c\x44\x2f\x6b\x65\x72\x6e\x65\x6c\x2d\x35\x2e\
\x31\x34\x2e\x30\x2d\x35\x37\x30\x2e\x32\x38\x2e\x31\x2e\x65\x6c\x39\x5f\x36\
\x2f\x6c\x69\x6e\x75\x78\x2d\x35\x2e\x31\x34\x2e\x30\x2d\x35\x37\x30\x2e\x32\
\x38\x2e\x31\x2e\x65\x6c\x39\x5f\x36\x2e\x78\x38\x36\x5f\x36\x34\x2f\x74\x6f\
\x6f\x6c\x73\x2f\x74\x65\x73\x74\x69\x6e\x67\x2f\x73\x65\x6c\x66\x74\x65\x73\
\x74\x73\x2f\x62\x70\x66\x2f\x70\x72\x6f\x67\x73\x2f\x74\x65\x73\x74\x5f\x6d\
\x6d\x61\x70\x2e\x63\0\x09\x6f\x75\x74\x5f\x76\x61\x6c\x20\x3d\x20\x69\x6e\x5f\
\x76\x61\x6c\x3b\0\x09\x69\x6e\x74\x20\x7a\x65\x72\x6f\x20\x3d\x20\x30\x2c\x20\
\x6f\x6e\x65\x20\x3d\x20\x31\x2c\x20\x74\x77\x6f\x20\x3d\x20\x32\x2c\x20\x66\
\x61\x72\x20\x3d\x20\x31\x35\x30\x30\x3b\0\x09\x62\x70\x66\x5f\x6d\x61\x70\x5f\
\x75\x70\x64\x61\x74\x65\x5f\x65\x6c\x65\x6d\x28\x26\x64\x61\x74\x61\x5f\x6d\
\x61\x70\x2c\x20\x26\x74\x77\x6f\x2c\x20\x28\x63\x6f\x6e\x73\x74\x20\x76\x6f\
\x69\x64\x20\x2a\x29\x26\x69\x6e\x5f\x76\x61\x6c\x2c\x20\x30\x29\x3b\0\x09\x70\
\x20\x3d\x20\x62\x70\x66\x5f\x6d\x61\x70\x5f\x6c\x6f\x6f\x6b\x75\x70\x5f\x65\
\x6c\x65\x6d\x28\x26\x64\x61\x74\x61\x5f\x6d\x61\x70\x2c\x20\x26\x7a\x65\x72\
\x6f\x29\x3b\0\x09\x69\x66\x20\x28\x70\x29\x20\x7b\0\x09\x09\x76\x61\x6c\x20\
\x3d\x20\x28\x2a\x70\x29\x20\x2a\x20\x32\x3b\0\x09\x09\x62\x70\x66\x5f\x6d\x61\
\x70\x5f\x75\x70\x64\x61\x74\x65\x5f\x65\x6c\x65\x6d\x28\x26\x64\x61\x74\x61\
\x5f\x6d\x61\x70\x2c\x20\x26\x6f\x6e\x65\x2c\x20\x26\x76\x61\x6c\x2c\x20\x30\
\x29\x3b\0\x09\x76\x61\x6c\x20\x3d\x20\x69\x6e\x5f\x76\x61\x6c\x20\x2a\x20\x33\
\x3b\0\x09\x62\x70\x66\x5f\x6d\x61\x70\x5f\x75\x70\x64\x61\x74\x65\x5f\x65\x6c\
\x65\x6d\x28\x26\x64\x61\x74\x61\x5f\x6d\x61\x70\x2c\x20\x26\x66\x61\x72\x2c\
\x20\x26\x76\x61\x6c\x2c\x20\x30\x29\x3b\0\x09\x72\x65\x74\x75\x72\x6e\x20\x30\
\x3b\0\x6c\x69\x63\x65\x6e\x73\x65\0\x2e\x62\x73\x73\0\x2e\x6d\x61\x70\x73\0\
\x72\x61\x77\x5f\x74\x72\x61\x63\x65\x70\x6f\x69\x6e\x74\x2f\x73\x79\x73\x5f\
\x65\x6e\x74\x65\x72\0\0\0\0\0\0\0\0\x9f\xeb\x01\0\x20\0\0\0\0\0\0\0\x14\0\0\0\
\x14\0\0\0\x2c\x01\0\0\x40\x01\0\0\0\0\0\0\x08\0\0\0\x7c\x02\0\0\x01\0\0\0\0\0\
\0\0\x17\0\0\0\x10\0\0\0\x7c\x02\0\0\x12\0\0\0\0\0\0\0\x9d\0\0\0\x21\x01\0\0\
\x0c\x84\0\0\x18\0\0\0\x9d\0\0\0\x21\x01\0\0\x0a\x84\0\0\x38\0\0\0\x9d\0\0\0\
\x34\x01\0\0\x06\x78\0\0\x48\0\0\0\x9d\0\0\0\x34\x01\0\0\x10\x78\0\0\x58\0\0\0\
\x9d\0\0\0\x34\x01\0\0\x19\x78\0\0\x68\0\0\0\x9d\0\0\0\x34\x01\0\0\x22\x78\0\0\
\x80\0\0\0\x9d\0\0\0\x61\x01\0\0\x02\x90\0\0\xc0\0\0\0\x9d\0\0\0\xa2\x01\0\0\
\x06\x9c\0\0\xd8\0\0\0\x9d\0\0\0\xce\x01\0\0\x06\xa0\0\0\xe0\0\0\0\x9d\0\0\0\
\xd8\x01\0\0\x0a\xa4\0\0\xe8\0\0\0\x9d\0\0\0\xd8\x01\0\0\x0e\xa4\0\0\xf0\0\0\0\
\x9d\0\0\0\xd8\x01\0\0\x07\xa4\0\0\x18\x01\0\0\x9d\0\0\0\xea\x01\0\0\x03\xa8\0\
\0\x38\x01\0\0\x9d\0\0\0\x1b\x02\0\0\x08\xb8\0\0\x40\x01\0\0\x9d\0\0\0\x1b\x02\
\0\0\x0f\xb8\0\0\x48\x01\0\0\x9d\0\0\0\x1b\x02\0\0\x06\xb8\0\0\x70\x01\0\0\x9d\
\0\0\0\x2e\x02\0\0\x02\xbc\0\0\x90\x01\0\0\x9d\0\0\0\x5e\x02\0\0\x02\xc4\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\x03\0\0\0\x20\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\x40\0\0\0\0\0\0\0\xaa\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x09\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\xf0\0\0\0\0\0\0\0\xd8\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\
\0\x18\0\0\0\0\0\0\0\x11\0\0\0\x01\0\0\0\x06\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xc8\
\x01\0\0\0\0\0\0\xa0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\x2a\0\0\0\x01\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x68\x03\0\0\0\0\
\0\0\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x32\0\
\0\0\x08\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x70\x03\0\0\0\0\0\0\x10\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x37\0\0\0\x01\0\0\0\
\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x70\x03\0\0\0\0\0\0\x40\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x7f\0\0\0\x09\0\0\0\x40\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\xb0\x03\0\0\0\0\0\0\x70\0\0\0\0\0\0\0\x02\0\0\0\x03\0\0\0\
\x08\0\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\x9c\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\x20\x04\0\0\0\0\0\0\x11\x05\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\xa1\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x38\
\x09\0\0\0\0\0\0\x60\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0";

	*sz = sizeof(data) - 1;
	return (const void *)data;
}

#ifdef __cplusplus
struct test_mmap *test_mmap::open(const struct bpf_object_open_opts *opts) { return test_mmap__open_opts(opts); }
struct test_mmap *test_mmap::open_and_load() { return test_mmap__open_and_load(); }
int test_mmap::load(struct test_mmap *skel) { return test_mmap__load(skel); }
int test_mmap::attach(struct test_mmap *skel) { return test_mmap__attach(skel); }
void test_mmap::detach(struct test_mmap *skel) { test_mmap__detach(skel); }
void test_mmap::destroy(struct test_mmap *skel) { test_mmap__destroy(skel); }
const void *test_mmap::elf_bytes(size_t *sz) { return test_mmap__elf_bytes(sz); }
#endif /* __cplusplus */

__attribute__((unused)) static void
test_mmap__assert(struct test_mmap *s __attribute__((unused)))
{
#ifdef __cplusplus
#define _Static_assert static_assert
#endif
	_Static_assert(sizeof(s->bss->in_val) == 8, "unexpected size of 'in_val'");
	_Static_assert(sizeof(s->bss->out_val) == 8, "unexpected size of 'out_val'");
#ifdef __cplusplus
#undef _Static_assert
#endif
}

#endif /* __TEST_MMAP_SKEL_H__ */
