/* SPDX-License-Identifier: (LGPL-2.1 OR BSD-2-Clause) */

/* THIS FILE IS AUTOGENERATED BY BPFTOOL! */
#ifndef __XDPWALL_SKEL_H__
#define __XDPWALL_SKEL_H__

#include <errno.h>
#include <stdlib.h>
#include <bpf/libbpf.h>

#define BPF_SKEL_SUPPORTS_MAP_AUTO_ATTACH 1

struct xdpwall {
	struct bpf_object_skeleton *skeleton;
	struct bpf_object *obj;
	struct {
		struct bpf_map *v6_addr_map;
		struct bpf_map *v4_addr_map;
		struct bpf_map *v4_lpm_val_map;
		struct bpf_map *tcp_port_map;
		struct bpf_map *udp_port_map;
	} maps;
	struct {
		struct bpf_program *edgewall;
	} progs;
	struct {
		struct bpf_link *edgewall;
	} links;

#ifdef __cplusplus
	static inline struct xdpwall *open(const struct bpf_object_open_opts *opts = nullptr);
	static inline struct xdpwall *open_and_load();
	static inline int load(struct xdpwall *skel);
	static inline int attach(struct xdpwall *skel);
	static inline void detach(struct xdpwall *skel);
	static inline void destroy(struct xdpwall *skel);
	static inline const void *elf_bytes(size_t *sz);
#endif /* __cplusplus */
};

static void
xdpwall__destroy(struct xdpwall *obj)
{
	if (!obj)
		return;
	if (obj->skeleton)
		bpf_object__destroy_skeleton(obj->skeleton);
	free(obj);
}

static inline int
xdpwall__create_skeleton(struct xdpwall *obj);

static inline struct xdpwall *
xdpwall__open_opts(const struct bpf_object_open_opts *opts)
{
	struct xdpwall *obj;
	int err;

	obj = (struct xdpwall *)calloc(1, sizeof(*obj));
	if (!obj) {
		errno = ENOMEM;
		return NULL;
	}

	err = xdpwall__create_skeleton(obj);
	if (err)
		goto err_out;

	err = bpf_object__open_skeleton(obj->skeleton, opts);
	if (err)
		goto err_out;

	return obj;
err_out:
	xdpwall__destroy(obj);
	errno = -err;
	return NULL;
}

static inline struct xdpwall *
xdpwall__open(void)
{
	return xdpwall__open_opts(NULL);
}

static inline int
xdpwall__load(struct xdpwall *obj)
{
	return bpf_object__load_skeleton(obj->skeleton);
}

static inline struct xdpwall *
xdpwall__open_and_load(void)
{
	struct xdpwall *obj;
	int err;

	obj = xdpwall__open();
	if (!obj)
		return NULL;
	err = xdpwall__load(obj);
	if (err) {
		xdpwall__destroy(obj);
		errno = -err;
		return NULL;
	}
	return obj;
}

static inline int
xdpwall__attach(struct xdpwall *obj)
{
	return bpf_object__attach_skeleton(obj->skeleton);
}

static inline void
xdpwall__detach(struct xdpwall *obj)
{
	bpf_object__detach_skeleton(obj->skeleton);
}

static inline const void *xdpwall__elf_bytes(size_t *sz);

static inline int
xdpwall__create_skeleton(struct xdpwall *obj)
{
	struct bpf_object_skeleton *s;
	struct bpf_map_skeleton *map __attribute__((unused));
	int err;

	s = (struct bpf_object_skeleton *)calloc(1, sizeof(*s));
	if (!s)	{
		err = -ENOMEM;
		goto err;
	}

	s->sz = sizeof(*s);
	s->name = "xdpwall";
	s->obj = &obj->obj;

	/* maps */
	s->map_cnt = 5;
	s->map_skel_sz = 24;
	s->maps = (struct bpf_map_skeleton *)calloc(s->map_cnt,
			sizeof(*s->maps) > 24 ? sizeof(*s->maps) : 24);
	if (!s->maps) {
		err = -ENOMEM;
		goto err;
	}

	map = (struct bpf_map_skeleton *)((char *)s->maps + 0 * s->map_skel_sz);
	map->name = "v6_addr_map";
	map->map = &obj->maps.v6_addr_map;

	map = (struct bpf_map_skeleton *)((char *)s->maps + 1 * s->map_skel_sz);
	map->name = "v4_addr_map";
	map->map = &obj->maps.v4_addr_map;

	map = (struct bpf_map_skeleton *)((char *)s->maps + 2 * s->map_skel_sz);
	map->name = "v4_lpm_val_map";
	map->map = &obj->maps.v4_lpm_val_map;

	map = (struct bpf_map_skeleton *)((char *)s->maps + 3 * s->map_skel_sz);
	map->name = "tcp_port_map";
	map->map = &obj->maps.tcp_port_map;

	map = (struct bpf_map_skeleton *)((char *)s->maps + 4 * s->map_skel_sz);
	map->name = "udp_port_map";
	map->map = &obj->maps.udp_port_map;

	/* programs */
	s->prog_cnt = 1;
	s->prog_skel_sz = sizeof(*s->progs);
	s->progs = (struct bpf_prog_skeleton *)calloc(s->prog_cnt, s->prog_skel_sz);
	if (!s->progs) {
		err = -ENOMEM;
		goto err;
	}

	s->progs[0].name = "edgewall";
	s->progs[0].prog = &obj->progs.edgewall;
	s->progs[0].link = &obj->links.edgewall;

	s->data = xdpwall__elf_bytes(&s->data_sz);

	obj->skeleton = s;
	return 0;
err:
	bpf_object__destroy_skeleton(s);
	return err;
}

static inline const void *xdpwall__elf_bytes(size_t *sz)
{
	static const char data[] __attribute__((__aligned__(8))) = "\
\x7f\x45\x4c\x46\x02\x01\x01\0\0\0\0\0\0\0\0\0\x01\0\xf7\0\x01\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\xe0\x16\0\0\0\0\0\0\0\0\0\0\x40\0\0\0\0\0\x40\0\x09\0\
\x01\0\0\x2e\x73\x74\x72\x74\x61\x62\0\x2e\x73\x79\x6d\x74\x61\x62\0\x78\x64\
\x70\0\x6c\x69\x63\x65\x6e\x73\x65\0\x2e\x6d\x61\x70\x73\0\x78\x64\x70\x77\x61\
\x6c\x6c\x2e\x63\0\x65\x64\x67\x65\x77\x61\x6c\x6c\0\x76\x36\x5f\x61\x64\x64\
\x72\x5f\x6d\x61\x70\0\x76\x34\x5f\x61\x64\x64\x72\x5f\x6d\x61\x70\0\x76\x34\
\x5f\x6c\x70\x6d\x5f\x76\x61\x6c\x5f\x6d\x61\x70\0\x74\x63\x70\x5f\x70\x6f\x72\
\x74\x5f\x6d\x61\x70\0\x75\x64\x70\x5f\x70\x6f\x72\x74\x5f\x6d\x61\x70\0\x4c\
\x49\x43\x45\x4e\x53\x45\0\x2e\x72\x65\x6c\x78\x64\x70\0\x2e\x42\x54\x46\0\x2e\
\x42\x54\x46\x2e\x65\x78\x74\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\x23\0\0\0\x04\0\xf1\xff\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\0\
\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x2d\0\0\0\x12\0\x03\0\0\0\0\0\0\0\0\0\
\xf8\x03\0\0\0\0\0\0\x36\0\0\0\x11\0\x05\0\0\0\0\0\0\0\0\0\x20\0\0\0\0\0\0\0\
\x42\0\0\0\x11\0\x05\0\x20\0\0\0\0\0\0\0\x20\0\0\0\0\0\0\0\x4e\0\0\0\x11\0\x05\
\0\x40\0\0\0\0\0\0\0\x28\0\0\0\0\0\0\0\x5d\0\0\0\x11\0\x05\0\x68\0\0\0\0\0\0\0\
\x20\0\0\0\0\0\0\0\x6a\0\0\0\x11\0\x05\0\x88\0\0\0\0\0\0\0\x20\0\0\0\0\0\0\0\
\x77\0\0\0\x11\0\x04\0\0\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\xb4\0\0\0\x01\0\0\0\
\x61\x16\0\0\0\0\0\0\x16\x06\x7b\0\0\0\0\0\x61\x17\x04\0\0\0\0\0\xbf\x62\0\0\0\
\0\0\0\x07\x02\0\0\x0e\0\0\0\x2d\x72\x77\0\0\0\0\0\x71\x61\x0d\0\0\0\0\0\x64\
\x01\0\0\x08\0\0\0\x71\x63\x0c\0\0\0\0\0\x4c\x31\0\0\0\0\0\0\x56\x01\x72\0\x86\
\xdd\0\0\xbf\x61\0\0\0\0\0\0\x07\x01\0\0\x36\0\0\0\x2d\x71\x6f\0\0\0\0\0\xb4\
\x09\0\0\x36\0\0\0\xb4\x03\0\0\x01\0\0\0\x71\x68\x14\0\0\0\0\0\x56\x08\x1a\0\
\x11\0\0\0\xbf\x61\0\0\0\0\0\0\x07\x01\0\0\x3e\0\0\0\x2d\x71\x68\0\0\0\0\0\xb4\
\x08\0\0\x11\0\0\0\x69\x63\x38\0\0\0\0\0\x56\x03\x19\0\x1a\x0a\0\0\xbf\x62\0\0\
\0\0\0\0\x07\x02\0\0\x3f\0\0\0\x2d\x72\x62\0\0\0\0\0\x71\x12\0\0\0\0\0\0\x54\
\x02\0\0\x30\0\0\0\x16\x02\x07\0\0\0\0\0\xbf\x62\0\0\0\0\0\0\x07\x02\0\0\x66\0\
\0\0\x2d\x72\x5c\0\0\0\0\0\xb4\x09\0\0\x66\0\0\0\xb4\x03\0\0\x01\0\0\0\x71\x68\
\x44\0\0\0\0\0\x05\0\x06\0\0\0\0\0\xbf\x62\0\0\0\0\0\0\x07\x02\0\0\x52\0\0\0\
\x2d\x72\x55\0\0\0\0\0\xb4\x09\0\0\x52\0\0\0\xb4\x03\0\0\0\0\0\0\x71\x68\x47\0\
\0\0\0\0\xbf\x12\0\0\0\0\0\0\x16\x08\x03\0\x06\0\0\0\xb4\0\0\0\x02\0\0\0\x16\
\x08\x4e\0\x3a\0\0\0\x56\x08\x4c\0\x11\0\0\0\x16\x03\x04\0\0\0\0\0\x07\x02\0\0\
\x08\0\0\0\x18\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x05\0\x1c\0\0\0\0\0\x61\x21\x0c\
\0\0\0\0\0\x63\x1a\xf8\xff\0\0\0\0\xbf\xa3\0\0\0\0\0\0\x07\x03\0\0\xf8\xff\xff\
\xff\x18\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x63\x9a\xf0\xff\0\0\0\0\xbf\x29\0\0\0\
\0\0\0\xbf\x32\0\0\0\0\0\0\x85\0\0\0\x01\0\0\0\x61\x91\x0c\0\0\0\0\0\x63\x1a\
\xfc\xff\0\0\0\0\xb4\x01\0\0\x20\0\0\0\x63\x1a\xf8\xff\0\0\0\0\xbf\xa2\0\0\0\0\
\0\0\x07\x02\0\0\xf8\xff\xff\xff\x18\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x85\0\0\0\
\x01\0\0\0\x61\x91\x10\0\0\0\0\0\x61\xa9\xf0\xff\0\0\0\0\xb4\x02\0\0\x20\0\0\0\
\x63\x2a\xf8\xff\0\0\0\0\x63\x1a\xfc\xff\0\0\0\0\xbf\xa2\0\0\0\0\0\0\x07\x02\0\
\0\xf8\xff\xff\xff\x18\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x85\0\0\0\x01\0\0\0\xbc\
\x91\0\0\0\0\0\0\x0f\x16\0\0\0\0\0\0\xb4\0\0\0\x01\0\0\0\x2d\x76\x27\0\0\0\0\0\
\x16\x08\x12\0\x11\0\0\0\x56\x08\x25\0\x06\0\0\0\xbf\x61\0\0\0\0\0\0\x07\x01\0\
\0\x14\0\0\0\x2d\x71\x22\0\0\0\0\0\x61\x67\x0c\0\0\0\0\0\x69\x61\x02\0\0\0\0\0\
\xdc\x01\0\0\x10\0\0\0\x63\x1a\xf8\xff\0\0\0\0\xbf\xa2\0\0\0\0\0\0\x07\x02\0\0\
\xf8\xff\xff\xff\x18\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x85\0\0\0\x01\0\0\0\x54\
\x07\0\0\0\x17\0\0\xb4\0\0\0\x01\0\0\0\x16\x07\x16\0\0\x02\0\0\xb4\0\0\0\x02\0\
\0\0\x05\0\x14\0\0\0\0\0\xbf\x61\0\0\0\0\0\0\x07\x01\0\0\x08\0\0\0\x2d\x71\x11\
\0\0\0\0\0\x69\x67\0\0\0\0\0\0\x69\x61\x02\0\0\0\0\0\xdc\x01\0\0\x10\0\0\0\x63\
\x1a\xf8\xff\0\0\0\0\xbf\xa2\0\0\0\0\0\0\x07\x02\0\0\xf8\xff\xff\xff\x18\x01\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\x85\0\0\0\x01\0\0\0\xdc\x07\0\0\x10\0\0\0\x63\x7a\
\xf8\xff\0\0\0\0\xbf\xa2\0\0\0\0\0\0\x07\x02\0\0\xf8\xff\xff\xff\x18\x01\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\x85\0\0\0\x01\0\0\0\xb4\0\0\0\x01\0\0\0\x95\0\0\0\0\0\0\
\0\x47\x50\x4c\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x98\x01\0\0\0\0\0\0\x01\0\0\0\
\x04\0\0\0\xd0\x01\0\0\0\0\0\0\x01\0\0\0\x05\0\0\0\x30\x02\0\0\0\0\0\0\x01\0\0\
\0\x06\0\0\0\x80\x02\0\0\0\0\0\0\x01\0\0\0\x06\0\0\0\x10\x03\0\0\0\0\0\0\x01\0\
\0\0\x07\0\0\0\x98\x03\0\0\0\0\0\0\x01\0\0\0\x08\0\0\0\xd0\x03\0\0\0\0\0\0\x01\
\0\0\0\x08\0\0\0\x9f\xeb\x01\0\x18\0\0\0\0\0\0\0\xec\x04\0\0\xec\x04\0\0\x5b\
\x07\0\0\0\0\0\0\0\0\0\x02\x03\0\0\0\x01\0\0\0\0\0\0\x01\x04\0\0\0\x20\0\0\x01\
\0\0\0\0\0\0\0\x03\0\0\0\0\x02\0\0\0\x04\0\0\0\x01\0\0\0\x05\0\0\0\0\0\0\x01\
\x04\0\0\0\x20\0\0\0\0\0\0\0\0\0\0\x02\x06\0\0\0\0\0\0\0\0\0\0\x03\0\0\0\0\x02\
\0\0\0\x04\0\0\0\x10\0\0\0\0\0\0\0\0\0\0\x02\x08\0\0\0\x19\0\0\0\x01\0\0\x04\
\x10\0\0\0\x22\0\0\0\x09\0\0\0\0\0\0\0\0\0\0\0\x03\0\0\x05\x10\0\0\0\x28\0\0\0\
\x0c\0\0\0\0\0\0\0\x31\0\0\0\x10\0\0\0\0\0\0\0\x3b\0\0\0\x14\0\0\0\0\0\0\0\x45\
\0\0\0\0\0\0\x08\x0b\0\0\0\x4a\0\0\0\0\0\0\x01\x01\0\0\0\x08\0\0\0\0\0\0\0\0\0\
\0\x03\0\0\0\0\x0a\0\0\0\x04\0\0\0\x10\0\0\0\x58\0\0\0\0\0\0\x08\x0e\0\0\0\x5f\
\0\0\0\0\0\0\x08\x0f\0\0\0\x65\0\0\0\0\0\0\x01\x02\0\0\0\x10\0\0\0\0\0\0\0\0\0\
\0\x03\0\0\0\0\x0d\0\0\0\x04\0\0\0\x08\0\0\0\x74\0\0\0\0\0\0\x08\x12\0\0\0\x7b\
\0\0\0\0\0\0\x08\x13\0\0\0\x81\0\0\0\0\0\0\x01\x04\0\0\0\x20\0\0\0\0\0\0\0\0\0\
\0\x03\0\0\0\0\x11\0\0\0\x04\0\0\0\x04\0\0\0\0\0\0\0\0\0\0\x02\x16\0\0\0\x8e\0\
\0\0\0\0\0\x01\x01\0\0\0\x08\0\0\x04\0\0\0\0\x04\0\0\x04\x20\0\0\0\x94\0\0\0\
\x01\0\0\0\0\0\0\0\x99\0\0\0\x05\0\0\0\x40\0\0\0\xa5\0\0\0\x07\0\0\0\x80\0\0\0\
\xa9\0\0\0\x15\0\0\0\xc0\0\0\0\xaf\0\0\0\0\0\0\x0e\x17\0\0\0\x01\0\0\0\0\0\0\0\
\0\0\0\x02\x12\0\0\0\0\0\0\0\x04\0\0\x04\x20\0\0\0\x94\0\0\0\x01\0\0\0\0\0\0\0\
\x99\0\0\0\x05\0\0\0\x40\0\0\0\xa5\0\0\0\x19\0\0\0\x80\0\0\0\xa9\0\0\0\x15\0\0\
\0\xc0\0\0\0\xbb\0\0\0\0\0\0\x0e\x1a\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\x02\x1d\0\0\
\0\0\0\0\0\0\0\0\x03\0\0\0\0\x02\0\0\0\x04\0\0\0\x0b\0\0\0\0\0\0\0\0\0\0\x02\
\x1f\0\0\0\0\0\0\0\0\0\0\x03\0\0\0\0\x02\0\0\0\x04\0\0\0\x08\0\0\0\0\0\0\0\0\0\
\0\x02\x21\0\0\0\0\0\0\0\0\0\0\x03\0\0\0\0\x02\0\0\0\x04\0\0\0\x0c\0\0\0\0\0\0\
\0\x05\0\0\x04\x28\0\0\0\x94\0\0\0\x1c\0\0\0\0\0\0\0\x99\0\0\0\x05\0\0\0\x40\0\
\0\0\xc7\0\0\0\x1e\0\0\0\x80\0\0\0\xd0\0\0\0\x20\0\0\0\xc0\0\0\0\xdb\0\0\0\x01\
\0\0\0\0\x01\0\0\xe5\0\0\0\0\0\0\x0e\x22\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\x02\x25\
\0\0\0\0\0\0\0\0\0\0\x03\0\0\0\0\x02\0\0\0\x04\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\
\x02\x02\0\0\0\0\0\0\0\0\0\0\x02\x0a\0\0\0\0\0\0\0\x04\0\0\x04\x20\0\0\0\x94\0\
\0\0\x24\0\0\0\0\0\0\0\x99\0\0\0\x05\0\0\0\x40\0\0\0\xa5\0\0\0\x26\0\0\0\x80\0\
\0\0\xa9\0\0\0\x27\0\0\0\xc0\0\0\0\xf4\0\0\0\0\0\0\x0e\x28\0\0\0\x01\0\0\0\0\0\
\0\0\0\0\0\x02\x0e\0\0\0\0\0\0\0\x04\0\0\x04\x20\0\0\0\x94\0\0\0\x24\0\0\0\0\0\
\0\0\x99\0\0\0\x05\0\0\0\x40\0\0\0\xa5\0\0\0\x26\0\0\0\x80\0\0\0\xa9\0\0\0\x2a\
\0\0\0\xc0\0\0\0\x01\x01\0\0\0\0\0\x0e\x2b\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\x02\
\x2e\0\0\0\x0e\x01\0\0\x06\0\0\x04\x18\0\0\0\x15\x01\0\0\x12\0\0\0\0\0\0\0\x1a\
\x01\0\0\x12\0\0\0\x20\0\0\0\x23\x01\0\0\x12\0\0\0\x40\0\0\0\x2d\x01\0\0\x12\0\
\0\0\x60\0\0\0\x3d\x01\0\0\x12\0\0\0\x80\0\0\0\x4c\x01\0\0\x12\0\0\0\xa0\0\0\0\
\0\0\0\0\x01\0\0\x0d\x02\0\0\0\x5b\x01\0\0\x2d\0\0\0\x5f\x01\0\0\x01\0\0\x0c\
\x2f\0\0\0\x68\x01\0\0\0\0\0\x01\x01\0\0\0\x08\0\0\x01\0\0\0\0\0\0\0\x03\0\0\0\
\0\x31\0\0\0\x04\0\0\0\x04\0\0\0\x6d\x01\0\0\0\0\0\x0e\x32\0\0\0\x01\0\0\0\x49\
\x07\0\0\x01\0\0\x0f\x04\0\0\0\x33\0\0\0\0\0\0\0\x04\0\0\0\x51\x07\0\0\x05\0\0\
\x0f\xa8\0\0\0\x18\0\0\0\0\0\0\0\x20\0\0\0\x1b\0\0\0\x20\0\0\0\x20\0\0\0\x23\0\
\0\0\x40\0\0\0\x28\0\0\0\x29\0\0\0\x68\0\0\0\x20\0\0\0\x2c\0\0\0\x88\0\0\0\x20\
\0\0\0\0\x69\x6e\x74\0\x5f\x5f\x41\x52\x52\x41\x59\x5f\x53\x49\x5a\x45\x5f\x54\
\x59\x50\x45\x5f\x5f\0\x69\x6e\x36\x5f\x61\x64\x64\x72\0\x69\x6e\x36\x5f\x75\0\
\x75\x36\x5f\x61\x64\x64\x72\x38\0\x75\x36\x5f\x61\x64\x64\x72\x31\x36\0\x75\
\x36\x5f\x61\x64\x64\x72\x33\x32\0\x5f\x5f\x75\x38\0\x75\x6e\x73\x69\x67\x6e\
\x65\x64\x20\x63\x68\x61\x72\0\x5f\x5f\x62\x65\x31\x36\0\x5f\x5f\x75\x31\x36\0\
\x75\x6e\x73\x69\x67\x6e\x65\x64\x20\x73\x68\x6f\x72\x74\0\x5f\x5f\x62\x65\x33\
\x32\0\x5f\x5f\x75\x33\x32\0\x75\x6e\x73\x69\x67\x6e\x65\x64\x20\x69\x6e\x74\0\
\x5f\x42\x6f\x6f\x6c\0\x74\x79\x70\x65\0\x6d\x61\x78\x5f\x65\x6e\x74\x72\x69\
\x65\x73\0\x6b\x65\x79\0\x76\x61\x6c\x75\x65\0\x76\x36\x5f\x61\x64\x64\x72\x5f\
\x6d\x61\x70\0\x76\x34\x5f\x61\x64\x64\x72\x5f\x6d\x61\x70\0\x6b\x65\x79\x5f\
\x73\x69\x7a\x65\0\x76\x61\x6c\x75\x65\x5f\x73\x69\x7a\x65\0\x6d\x61\x70\x5f\
\x66\x6c\x61\x67\x73\0\x76\x34\x5f\x6c\x70\x6d\x5f\x76\x61\x6c\x5f\x6d\x61\x70\
\0\x74\x63\x70\x5f\x70\x6f\x72\x74\x5f\x6d\x61\x70\0\x75\x64\x70\x5f\x70\x6f\
\x72\x74\x5f\x6d\x61\x70\0\x78\x64\x70\x5f\x6d\x64\0\x64\x61\x74\x61\0\x64\x61\
\x74\x61\x5f\x65\x6e\x64\0\x64\x61\x74\x61\x5f\x6d\x65\x74\x61\0\x69\x6e\x67\
\x72\x65\x73\x73\x5f\x69\x66\x69\x6e\x64\x65\x78\0\x72\x78\x5f\x71\x75\x65\x75\
\x65\x5f\x69\x6e\x64\x65\x78\0\x65\x67\x72\x65\x73\x73\x5f\x69\x66\x69\x6e\x64\
\x65\x78\0\x63\x74\x78\0\x65\x64\x67\x65\x77\x61\x6c\x6c\0\x63\x68\x61\x72\0\
\x4c\x49\x43\x45\x4e\x53\x45\0\x2f\x62\x75\x69\x6c\x64\x64\x69\x72\x2f\x62\x75\
\x69\x6c\x64\x2f\x42\x55\x49\x4c\x44\x2f\x6b\x65\x72\x6e\x65\x6c\x2d\x35\x2e\
\x31\x34\x2e\x30\x2d\x35\x37\x30\x2e\x32\x38\x2e\x31\x2e\x65\x6c\x39\x5f\x36\
\x2f\x6c\x69\x6e\x75\x78\x2d\x35\x2e\x31\x34\x2e\x30\x2d\x35\x37\x30\x2e\x32\
\x38\x2e\x31\x2e\x65\x6c\x39\x5f\x36\x2e\x78\x38\x36\x5f\x36\x34\x2f\x74\x6f\
\x6f\x6c\x73\x2f\x74\x65\x73\x74\x69\x6e\x67\x2f\x73\x65\x6c\x66\x74\x65\x73\
\x74\x73\x2f\x62\x70\x66\x2f\x70\x72\x6f\x67\x73\x2f\x78\x64\x70\x77\x61\x6c\
\x6c\x2e\x63\0\x69\x6e\x74\x20\x65\x64\x67\x65\x77\x61\x6c\x6c\x28\x73\x74\x72\
\x75\x63\x74\x20\x78\x64\x70\x5f\x6d\x64\x20\x2a\x63\x74\x78\x29\0\x09\x76\x6f\
\x69\x64\x20\x2a\x64\x61\x74\x61\x20\x3d\x20\x28\x76\x6f\x69\x64\x20\x2a\x29\
\x28\x6c\x6f\x6e\x67\x29\x28\x63\x74\x78\x2d\x3e\x64\x61\x74\x61\x29\x3b\0\x09\
\x69\x66\x20\x28\x21\x65\x74\x68\x29\0\x09\x70\x72\x6f\x74\x6f\x20\x3d\x20\x65\
\x74\x68\x2d\x3e\x68\x5f\x70\x72\x6f\x74\x6f\x3b\0\x09\x69\x66\x20\x28\x70\x72\
\x6f\x74\x6f\x20\x21\x3d\x20\x62\x70\x66\x5f\x68\x74\x6f\x6e\x73\x28\x45\x54\
\x48\x5f\x50\x5f\x49\x50\x56\x36\x29\x29\0\x09\x69\x6e\x66\x6f\x2d\x3e\x70\x72\
\x6f\x74\x6f\x20\x3d\x20\x69\x70\x36\x68\x2d\x3e\x6e\x65\x78\x74\x68\x64\x72\
\x3b\0\x09\x69\x66\x20\x28\x69\x6e\x66\x6f\x2d\x3e\x70\x72\x6f\x74\x6f\x20\x3d\
\x3d\x20\x49\x50\x50\x52\x4f\x54\x4f\x5f\x55\x44\x50\x29\0\x09\x76\x6f\x69\x64\
\x20\x2a\x65\x6e\x63\x61\x70\x5f\x64\x61\x74\x61\x20\x3d\x20\x75\x64\x70\x20\
\x2b\x20\x31\x3b\0\x09\x69\x66\x20\x28\x75\x64\x70\x20\x2b\x20\x31\x20\x3e\x20\
\x64\x61\x74\x61\x5f\x65\x6e\x64\x29\0\x09\x69\x66\x20\x28\x75\x64\x70\x2d\x3e\
\x64\x65\x73\x74\x20\x21\x3d\x20\x62\x70\x66\x5f\x68\x74\x6f\x6e\x73\x28\x36\
\x36\x36\x36\x29\x29\0\x09\x69\x66\x20\x28\x65\x6e\x63\x61\x70\x5f\x64\x61\x74\
\x61\x20\x2b\x20\x31\x20\x3e\x20\x64\x61\x74\x61\x5f\x65\x6e\x64\x29\0\x09\x69\
\x66\x20\x28\x2a\x28\x5f\x5f\x75\x38\x20\x2a\x29\x65\x6e\x63\x61\x70\x5f\x64\
\x61\x74\x61\x20\x26\x20\x30\x78\x33\x30\x29\x20\x7b\0\x09\x09\x69\x66\x20\x28\
\x69\x6e\x6e\x65\x72\x5f\x69\x70\x36\x68\x20\x2b\x20\x31\x20\x3e\x20\x64\x61\
\x74\x61\x5f\x65\x6e\x64\x29\0\x09\x09\x69\x6e\x66\x6f\x2d\x3e\x70\x72\x6f\x74\
\x6f\x20\x3d\x20\x69\x6e\x6e\x65\x72\x5f\x69\x70\x36\x68\x2d\x3e\x6e\x65\x78\
\x74\x68\x64\x72\x3b\0\x09\x09\x69\x66\x20\x28\x69\x6e\x6e\x65\x72\x5f\x69\x70\
\x34\x68\x20\x2b\x20\x31\x20\x3e\x20\x64\x61\x74\x61\x5f\x65\x6e\x64\x29\0\x09\
\x09\x69\x6e\x66\x6f\x2d\x3e\x70\x72\x6f\x74\x6f\x20\x3d\x20\x69\x6e\x6e\x65\
\x72\x5f\x69\x70\x34\x68\x2d\x3e\x70\x72\x6f\x74\x6f\x63\x6f\x6c\x3b\0\x09\x69\
\x66\x20\x28\x69\x6e\x66\x6f\x2e\x70\x72\x6f\x74\x6f\x20\x3d\x3d\x20\x49\x50\
\x50\x52\x4f\x54\x4f\x5f\x49\x43\x4d\x50\x56\x36\x29\0\x09\x69\x66\x20\x28\x69\
\x6e\x66\x6f\x2d\x3e\x74\x79\x70\x65\x20\x3d\x3d\x20\x56\x36\x29\x20\x7b\0\x09\
\x09\x09\x66\x69\x6c\x74\x65\x72\x5f\x69\x70\x76\x36\x5f\x61\x64\x64\x72\x28\
\x26\x69\x6e\x66\x6f\x2d\x3e\x69\x70\x2e\x69\x70\x76\x36\x2d\x3e\x73\x61\x64\
\x64\x72\x29\x3b\0\x09\x6c\x65\x61\x66\x20\x3d\x20\x62\x70\x66\x5f\x6d\x61\x70\
\x5f\x6c\x6f\x6f\x6b\x75\x70\x5f\x65\x6c\x65\x6d\x28\x26\x76\x36\x5f\x61\x64\
\x64\x72\x5f\x6d\x61\x70\x2c\x20\x69\x70\x76\x36\x61\x64\x64\x72\x29\x3b\0\x09\
\x09\x09\x66\x69\x6c\x74\x65\x72\x5f\x69\x70\x76\x34\x5f\x61\x64\x64\x72\x28\
\x69\x6e\x66\x6f\x2d\x3e\x69\x70\x2e\x69\x70\x76\x34\x2d\x3e\x73\x61\x64\x64\
\x72\x29\x3b\0\x09\x6c\x65\x61\x66\x20\x3d\x20\x62\x70\x66\x5f\x6d\x61\x70\x5f\
\x6c\x6f\x6f\x6b\x75\x70\x5f\x65\x6c\x65\x6d\x28\x26\x76\x34\x5f\x61\x64\x64\
\x72\x5f\x6d\x61\x70\x2c\x20\x26\x69\x70\x61\x64\x64\x72\x29\x3b\0\x09\x09\x09\
\x66\x69\x6c\x74\x65\x72\x5f\x69\x70\x76\x34\x5f\x6c\x70\x6d\x28\x69\x6e\x66\
\x6f\x2d\x3e\x69\x70\x2e\x69\x70\x76\x34\x2d\x3e\x73\x61\x64\x64\x72\x29\x3b\0\
\x09\x76\x34\x5f\x6b\x65\x79\x2e\x73\x72\x63\x20\x3d\x20\x69\x70\x61\x64\x64\
\x72\x3b\0\x09\x76\x34\x5f\x6b\x65\x79\x2e\x70\x72\x65\x66\x69\x78\x6c\x65\x6e\
\x20\x3d\x20\x33\x32\x3b\0\x09\x6c\x70\x6d\x5f\x76\x61\x6c\x20\x3d\x20\x62\x70\
\x66\x5f\x6d\x61\x70\x5f\x6c\x6f\x6f\x6b\x75\x70\x5f\x65\x6c\x65\x6d\x28\x26\
\x76\x34\x5f\x6c\x70\x6d\x5f\x76\x61\x6c\x5f\x6d\x61\x70\x2c\x20\x26\x76\x34\
\x5f\x6b\x65\x79\x29\x3b\0\x09\x09\x09\x66\x69\x6c\x74\x65\x72\x5f\x69\x70\x76\
\x34\x5f\x6c\x70\x6d\x28\x69\x6e\x66\x6f\x2d\x3e\x69\x70\x2e\x69\x70\x76\x34\
\x2d\x3e\x64\x61\x64\x64\x72\x29\x3b\0\x09\x69\x66\x20\x28\x6f\x66\x66\x73\x65\
\x74\x20\x3e\x20\x32\x35\x35\x20\x7c\x7c\x20\x64\x61\x74\x61\x20\x2b\x20\x6f\
\x66\x66\x73\x65\x74\x20\x3e\x20\x64\x61\x74\x61\x5f\x65\x6e\x64\x29\0\x09\x69\
\x66\x20\x28\x69\x6e\x66\x6f\x2d\x3e\x70\x72\x6f\x74\x6f\x20\x3d\x3d\x20\x49\
\x50\x50\x52\x4f\x54\x4f\x5f\x54\x43\x50\x29\x20\x7b\0\x09\x69\x66\x20\x28\x74\
\x63\x70\x20\x2b\x20\x31\x20\x3e\x20\x64\x61\x74\x61\x5f\x65\x6e\x64\x29\0\x09\
\x72\x65\x74\x75\x72\x6e\x20\x28\x74\x63\x70\x5f\x66\x6c\x61\x67\x5f\x77\x6f\
\x72\x64\x28\x74\x63\x70\x29\x20\x26\0\x09\x69\x6e\x66\x6f\x2d\x3e\x64\x70\x6f\
\x72\x74\x20\x3d\x20\x62\x70\x66\x5f\x6e\x74\x6f\x68\x73\x28\x74\x63\x70\x2d\
\x3e\x64\x65\x73\x74\x29\x3b\0\x09\x5f\x5f\x75\x38\x20\x2a\x6c\x65\x61\x66\x20\
\x3d\x20\x62\x70\x66\x5f\x6d\x61\x70\x5f\x6c\x6f\x6f\x6b\x75\x70\x5f\x65\x6c\
\x65\x6d\x28\x26\x74\x63\x70\x5f\x70\x6f\x72\x74\x5f\x6d\x61\x70\x2c\x20\x26\
\x70\x6f\x72\x74\x29\x3b\0\x09\x69\x66\x20\x28\x6d\x61\x74\x63\x68\x5f\x69\x6e\
\x66\x6f\x2e\x69\x73\x5f\x74\x63\x70\x20\x26\x26\x20\x21\x6d\x61\x74\x63\x68\
\x5f\x69\x6e\x66\x6f\x2e\x69\x73\x5f\x74\x63\x70\x5f\x73\x79\x6e\x29\0\x09\x69\
\x6e\x66\x6f\x2d\x3e\x73\x70\x6f\x72\x74\x20\x3d\x20\x62\x70\x66\x5f\x6e\x74\
\x6f\x68\x73\x28\x75\x64\x70\x2d\x3e\x73\x6f\x75\x72\x63\x65\x29\x3b\0\x09\x69\
\x6e\x66\x6f\x2d\x3e\x64\x70\x6f\x72\x74\x20\x3d\x20\x62\x70\x66\x5f\x6e\x74\
\x6f\x68\x73\x28\x75\x64\x70\x2d\x3e\x64\x65\x73\x74\x29\x3b\0\x09\x5f\x5f\x75\
\x31\x36\x20\x2a\x6c\x65\x61\x66\x20\x3d\x20\x62\x70\x66\x5f\x6d\x61\x70\x5f\
\x6c\x6f\x6f\x6b\x75\x70\x5f\x65\x6c\x65\x6d\x28\x26\x75\x64\x70\x5f\x70\x6f\
\x72\x74\x5f\x6d\x61\x70\x2c\x20\x26\x70\x6f\x72\x74\x29\x3b\0\x7d\0\x6c\x69\
\x63\x65\x6e\x73\x65\0\x2e\x6d\x61\x70\x73\0\x78\x64\x70\0\0\x9f\xeb\x01\0\x20\
\0\0\0\0\0\0\0\x14\0\0\0\x14\0\0\0\x6c\x03\0\0\x80\x03\0\0\0\0\0\0\x08\0\0\0\
\x57\x07\0\0\x01\0\0\0\0\0\0\0\x30\0\0\0\x10\0\0\0\x57\x07\0\0\x36\0\0\0\0\0\0\
\0\x75\x01\0\0\xf7\x01\0\0\0\xf8\x04\0\x08\0\0\0\x75\x01\0\0\x18\x02\0\0\x23\
\x04\x05\0\x10\0\0\0\x75\x01\0\0\x41\x02\0\0\x06\x28\x05\0\x38\0\0\0\x75\x01\0\
\0\x4c\x02\0\0\x0f\x34\x05\0\x58\0\0\0\x75\x01\0\0\x63\x02\0\0\x06\x38\x05\0\
\x88\0\0\0\x75\x01\0\0\x88\x02\0\0\x16\xc8\x04\0\x90\0\0\0\x75\x01\0\0\xa6\x02\
\0\0\x06\xdc\x04\0\x98\0\0\0\x75\x01\0\0\xc7\x02\0\0\x19\x10\x04\0\xa8\0\0\0\
\x75\x01\0\0\xe4\x02\0\0\x06\x18\x04\0\xb8\0\0\0\x75\x01\0\0\xfd\x02\0\0\x0b\
\x24\x04\0\xc0\0\0\0\x75\x01\0\0\xfd\x02\0\0\x06\x24\x04\0\xc8\0\0\0\x75\x01\0\
\0\x20\x03\0\0\x11\x38\x04\0\xd8\0\0\0\x75\x01\0\0\x20\x03\0\0\x06\x38\x04\0\
\xe0\0\0\0\x75\x01\0\0\x40\x03\0\0\x06\x44\x04\0\xe8\0\0\0\x75\x01\0\0\x40\x03\
\0\0\x1a\x44\x04\0\xf0\0\0\0\x75\x01\0\0\x40\x03\0\0\x06\x44\x04\0\xf8\0\0\0\
\x75\x01\0\0\x63\x03\0\0\x12\x50\x04\0\x08\x01\0\0\x75\x01\0\0\x63\x03\0\0\x07\
\x50\x04\0\x20\x01\0\0\x75\x01\0\0\x84\x03\0\0\x1d\x60\x04\0\x30\x01\0\0\x75\
\x01\0\0\xa9\x03\0\0\x12\x78\x04\0\x40\x01\0\0\x75\x01\0\0\xa9\x03\0\0\x07\x78\
\x04\0\x58\x01\0\0\x75\x01\0\0\xca\x03\0\0\x1d\x88\x04\0\x68\x01\0\0\x75\x01\0\
\0\xf0\x03\0\0\x06\x50\x05\0\x88\x01\0\0\x75\x01\0\0\x13\x04\0\0\x06\x5c\x02\0\
\x90\x01\0\0\x75\x01\0\0\x2c\x04\0\0\x25\x64\x02\0\x98\x01\0\0\x75\x01\0\0\x58\
\x04\0\0\x09\xe0\x01\0\xb0\x01\0\0\x75\x01\0\0\x8d\x04\0\0\x24\x70\x02\0\xd0\
\x01\0\0\x75\x01\0\0\xb8\x04\0\0\x09\x04\x02\0\0\x02\0\0\x75\x01\0\0\xec\x04\0\
\0\x23\x78\x02\0\x08\x02\0\0\x75\x01\0\0\x16\x05\0\0\x0d\x2c\x02\0\x18\x02\0\0\
\x75\x01\0\0\x2c\x05\0\0\x13\x30\x02\0\x30\x02\0\0\x75\x01\0\0\x44\x05\0\0\x0c\
\x38\x02\0\x48\x02\0\0\x75\x01\0\0\x7e\x05\0\0\x23\x80\x02\0\x58\x02\0\0\x75\
\x01\0\0\x2c\x05\0\0\x13\x30\x02\0\x68\x02\0\0\x75\x01\0\0\x16\x05\0\0\x0d\x2c\
\x02\0\x80\x02\0\0\x75\x01\0\0\x44\x05\0\0\x0c\x38\x02\0\x98\x02\0\0\x75\x01\0\
\0\xa8\x05\0\0\x1b\x9c\x02\0\xb0\x02\0\0\x75\x01\0\0\xa8\x05\0\0\x06\x9c\x02\0\
\xb8\x02\0\0\x75\x01\0\0\xd7\x05\0\0\x06\xb4\x03\0\xc8\x02\0\0\x75\x01\0\0\xfa\
\x05\0\0\x0a\x0c\x03\0\xd8\x02\0\0\x75\x01\0\0\xfa\x05\0\0\x06\x0c\x03\0\xe0\
\x02\0\0\x75\x01\0\0\x13\x06\0\0\x0a\xc0\x02\0\xe8\x02\0\0\x75\x01\0\0\x31\x06\
\0\0\x10\x1c\x03\0\x10\x03\0\0\x75\x01\0\0\x56\x06\0\0\x0f\x74\x03\0\x28\x03\0\
\0\x75\x01\0\0\x13\x06\0\0\x1d\xc0\x02\0\x38\x03\0\0\x75\x01\0\0\x8f\x06\0\0\
\x06\x98\x05\0\x50\x03\0\0\x75\x01\0\0\xe4\x02\0\0\x0a\x48\x03\0\x60\x03\0\0\
\x75\x01\0\0\xe4\x02\0\0\x06\x48\x03\0\x68\x03\0\0\x75\x01\0\0\xc1\x06\0\0\x10\
\x54\x03\0\x70\x03\0\0\x75\x01\0\0\xe8\x06\0\0\x10\x58\x03\0\x98\x03\0\0\x75\
\x01\0\0\x0d\x07\0\0\x10\x90\x03\0\xb0\x03\0\0\x75\x01\0\0\xc1\x06\0\0\x10\x54\
\x03\0\xd0\x03\0\0\x75\x01\0\0\x0d\x07\0\0\x10\x90\x03\0\xf0\x03\0\0\x75\x01\0\
\0\x47\x07\0\0\x01\xa8\x05\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\x01\0\0\0\x03\0\0\0\x20\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x40\0\0\0\0\0\0\0\x95\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x09\0\0\0\x02\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xd8\0\0\0\0\0\0\0\xf0\0\0\0\0\0\0\0\x01\0\
\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\x18\0\0\0\0\0\0\0\x11\0\0\0\x01\0\0\0\x06\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\xc8\x01\0\0\0\0\0\0\xf8\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\x08\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x15\0\0\0\x01\0\0\0\x03\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\xc0\x05\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\x1d\0\0\0\x01\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\xc8\x05\0\0\0\0\0\0\xa8\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\x7f\0\0\0\x09\0\0\0\x40\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x70\x06\0\0\0\
\0\0\0\x70\0\0\0\0\0\0\0\x02\0\0\0\x03\0\0\0\x08\0\0\0\0\0\0\0\x10\0\0\0\0\0\0\
\0\x87\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xe0\x06\0\0\0\0\0\0\x5f\
\x0c\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x8c\0\0\0\
\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x40\x13\0\0\0\0\0\0\xa0\x03\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0";

	*sz = sizeof(data) - 1;
	return (const void *)data;
}

#ifdef __cplusplus
struct xdpwall *xdpwall::open(const struct bpf_object_open_opts *opts) { return xdpwall__open_opts(opts); }
struct xdpwall *xdpwall::open_and_load() { return xdpwall__open_and_load(); }
int xdpwall::load(struct xdpwall *skel) { return xdpwall__load(skel); }
int xdpwall::attach(struct xdpwall *skel) { return xdpwall__attach(skel); }
void xdpwall::detach(struct xdpwall *skel) { xdpwall__detach(skel); }
void xdpwall::destroy(struct xdpwall *skel) { xdpwall__destroy(skel); }
const void *xdpwall::elf_bytes(size_t *sz) { return xdpwall__elf_bytes(sz); }
#endif /* __cplusplus */

__attribute__((unused)) static void
xdpwall__assert(struct xdpwall *s __attribute__((unused)))
{
#ifdef __cplusplus
#define _Static_assert static_assert
#endif
#ifdef __cplusplus
#undef _Static_assert
#endif
}

#endif /* __XDPWALL_SKEL_H__ */
